.. robotpy-build documentation master file, created by
   sphinx-quickstart on Sun Apr  5 18:38:00 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

robotpy-build: (mostly) automated C++ wrapping for Python 
=========================================================

.. toctree::
   :maxdepth: 2
   :caption: Introduction

   intro
   install
   demo

.. toctree::
   :maxdepth: 2
   :caption: User's Guide

   autowrap
   deps
   type_casters
   platform
   tips
   tools

.. toctree::
   :caption: Configuration
   :maxdepth: 2

   config/pyproject
   config/hookdata

.. toctree::
   :caption: Support
   :maxdepth: 2

   troubleshooting
   support


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
